import 'package:dynamic_widget/dynamic_widget.dart';
import 'package:layout_form_builder/parser/card_parser.dart';
import 'package:layout_form_builder/parser/checkbox_group_parser.dart';
import 'package:layout_form_builder/parser/drop_down_parser.dart';
import 'package:layout_form_builder/parser/flexible_parser.dart';
import 'package:layout_form_builder/parser/full_size_column_parser.dart';
import 'package:layout_form_builder/parser/partial_size_column_parser.dart';
import 'package:layout_form_builder/parser/text_field_parser.dart';
import 'package:nui_form/component/nuif_text.dart';

class EFormLayoutRenderer{
  late String _baseUrl;
  late NUIFTextStyle _textStyle;

  static EFormLayoutRenderer? _instance;

  EFormLayoutRenderer._builder(EFormLayoutRendererBuilder builder){
    _baseUrl = builder._baseUrl;
    _textStyle = builder._textStyle;
    _instance = this;

    _initDynamicParsers();
  }

  void _initDynamicParsers(){
    DynamicWidgetBuilder.addParser(CardParser());
    DynamicWidgetBuilder.addParser(TextFieldParser());
    DynamicWidgetBuilder.addParser(FlexibleParser());
    DynamicWidgetBuilder.addParser(FullSizeColumnParser());
    DynamicWidgetBuilder.addParser(PartialSizeColumnParser());
    DynamicWidgetBuilder.addParser(DropDownParser());
    DynamicWidgetBuilder.addParser(CheckboxGroupParser());
  }

  static EFormLayoutRenderer get instance{
    if(_instance == null) throw Exception("EFormLayoutRenderer: You have not initialized the renderer");
    return _instance!;
  }

  static bool get initialized{
    return _instance != null;
  }

  NUIFTextStyle get textStyle{
    return _textStyle;
  }

  String get baseUrl{
    return _baseUrl;
  }
}

class EFormLayoutRendererBuilder{
  late String _baseUrl;
  late NUIFTextStyle _textStyle;

  EFormLayoutRendererBuilder baseUrl(String baseUrl){
    _baseUrl = baseUrl;
    return this;
  }

  EFormLayoutRendererBuilder textStyle(NUIFTextStyle style){
    _textStyle = style;
    return this;
  }

  EFormLayoutRenderer build(){
    final renderer = EFormLayoutRenderer._builder(this);
    return renderer;
  }
}