import 'dart:convert';
import 'dart:io';
import 'package:flutter/material.dart';
import 'package:layout_form_builder/page_route_mgmt.dart';
import 'package:http/http.dart' as http;
import 'util.dart';

class FormListPage extends StatefulWidget {
  @override
  _FormListPageState createState() => _FormListPageState();
}

class FormObj {
  final String name;
  final PageType pageType;

  FormObj({required this.name, required this.pageType});
}

class _FormListPageState extends State<FormListPage> {
  /// Will used to access the Animated list
  final GlobalKey<AnimatedListState> listKey = GlobalKey<AnimatedListState>();

  /// This holds the items
  List<FormObj> _forms = [];
  late PageRouteMgmt routeMgmt;

  _loadFormBuilderLatest() async {
    try {
      // final response = await http.get(
      //   Uri.parse(
      //       'http://inglabcloud.hopto.org:6080/formbuilder/editor/widget/list'),
      //   headers: {
      //     "Authorization":
      //         " Bearer eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJzdWIiOiIxIiwiaXNzIjoiSU5HTEFCIiwiZXhwIjoxNjIyMTgwNjUzfQ.iUeL1GMIr0w6TgCHtxCLAKrfQ7KdMa3gMjsIQulqfZA",
      //   },
      // );
      // print("formbuilder response is: ${response.body}");

      final resp = await http.post(
          Uri.parse(
              "http://inglabcloud.hopto.org:6080/formbuilder/auth/admin/login"),
          headers: <String, String>{
            'Content-Type': 'application/json; charset=UTF-8',
          },
          body: jsonEncode({
            "username": "superadmin",
            "password": "Password*123",
            "grantType": "password"
          }));
      print("formbuilder response is: ${resp.body}");
    } catch (ex, stacktrace) {
      print("ex: $ex, stacktrace: $stacktrace");
    }
  }

  @override
  void initState() {
    _loadItems();
    super.initState();
  }

  Future<void> _loadItems() async {
    List<FormObj> items = List<FormObj>.generate(3, (i) {
      String name = "";
      switch (i) {
        case 0:
          name = "Claim Form For Group Hospitalisation & Surgical Benefit";
          break;
        case 1:
          name = "Death Claim Form";
          break;
        case 2:
          name = "Direct Credit Form";
          break;
      }

      return FormObj(name: name, pageType: PageType.PAGE_FORM_HOSPITALISATION);
    });

    for (FormObj item in items) {
      // 1) Wait for one second
      await Future.delayed(Duration(milliseconds: 150));
      // 2) Adding data to actual variable that holds the item.
      _forms.add(item);
      // 3) Telling animated list to start animation
      listKey.currentState?.insertItem(_forms.length - 1);
    }
  }

  @override
  Widget build(BuildContext context) {
    routeMgmt = PageRouteMgmt(context);

    return Scaffold(
        appBar: AppBar(
          title: Text('GE Forms', style: TextStyle(fontFamily: 'Lato')),
        ),
        backgroundColor: Colors.grey[300],
        body: Stack(
          children: [
            Positioned(
                left: 0,
                right: -100,
                bottom: 0,
                child: Padding(
                    padding: EdgeInsets.all(40),
                    child: Container(
                        width: double.infinity,
                        height: 300,
                        child: Image.asset('assets/images/gelogo.png',
                            fit: BoxFit.contain)))),
            Padding(
                padding: EdgeInsets.fromLTRB(5, 12, 5, 12),
                child: AnimatedList(
                  key: listKey,
                  initialItemCount: _forms.length,
                  itemBuilder: (context, index, animation) {
                    return _slideIt(context, index, animation); // Refer step 3
                  },
                ))
          ],
        ));
  }

  Widget _slideIt(BuildContext context, int index, animation) {
    FormObj form = _forms[index];
    TextStyle textStyle = TextStyle(fontFamily: 'Lato', fontSize: 25);
    TextStyle textStyle2 = TextStyle(fontFamily: 'Lato', fontSize: 20);
    return SlideTransition(
        position: Tween<Offset>(
          begin: const Offset(-1, 0),
          end: Offset(0, 0),
        ).animate(animation),
        child: InkWell(
          onTap: () => routeMgmt.push(form.pageType, null),
          child: Padding(
            padding: EdgeInsets.fromLTRB(15, 15, 15, 15),
            child: Card(
              elevation: 5,
              shape: RoundedRectangleBorder(
                  borderRadius: BorderRadius.circular(12)),
              color: Colors.white,
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Padding(
                      padding: EdgeInsets.all(20),
                      child: Row(
                        crossAxisAlignment: CrossAxisAlignment.center,
                        children: [
                          Text(form.name, style: textStyle),
                          Expanded(child: Container()),
                          Icon(Icons.chevron_right,
                              color: HexColor.fromHex('ee1c25'), size: 48)
                        ],
                      )),
                  Padding(
                      padding: EdgeInsets.all(20),
                      child: Row(
                        crossAxisAlignment: CrossAxisAlignment.center,
                        children: [
                          Text('GE LifeAssurance form 2021', style: textStyle2)
                        ],
                      )),
                ],
              ),
            ),
          ),
        ));
  }
}
