import 'package:flutter/material.dart';

import 'form_list_page.dart';
import 'gen_pdf_page.dart';
import 'hospitalisation_page.dart';

enum PageType { PAGE_FORMS, PAGE_FORM_HOSPITALISATION, PAGE_FORM_GEN_PDF }

extension PageTypeExtension on PageType {
  String get name {
    switch (this) {
      case PageType.PAGE_FORMS:
        return '/';
      case PageType.PAGE_FORM_HOSPITALISATION:
        return '/formHospitalisation';
      case PageType.PAGE_FORM_GEN_PDF:
        return '/genPdf';
      default:
        return '/';
    }
  }
}

class Page {
  final PageType type;
  final Widget scr;

  Page({required this.type, required this.scr});
}

class PageRouteMgmt {
  late BuildContext buildContext;
  //List<Page> pages = [];

  PageRouteMgmt(BuildContext context) {
    buildContext = context;
  }

  MaterialPageRoute<dynamic> onGenerateRoute(RouteSettings settings) {
    Widget? widget;
    final arguments = settings.arguments;
    final String? pageName = settings.name;
    if (pageName != null) {
      print("pageName: $pageName");
      if (pageName == PageType.PAGE_FORMS.name) {
        widget = FormListPage();
      } else if (pageName == PageType.PAGE_FORM_HOSPITALISATION.name) {
        widget = HospitalisationPage();
      } else if (pageName == PageType.PAGE_FORM_GEN_PDF.name) {
        widget = GenPdfPage(pageId: arguments as String);
      }
    }
    if (widget == null) widget = FormListPage();

    return MaterialPageRoute(
      builder: (context) {
        return widget!;
      },
    );
  }

  String getInitRoute() {
    return PageType.PAGE_FORMS.name;
  }

  push(PageType type, Object? argument) {
    Navigator.pushNamed(buildContext, type.name, arguments: argument);
  }

  pop() {
    Navigator.pop(buildContext);
  }
}
